#
# spec file for package adminer
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Jimmy Berry <jimmy@boombatower.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# pending package submissions to Factory
%bcond_with elasticsearch
%bcond_with mongodb
%bcond_with mssql
Name:           adminer
Version:        4.6.2
Release:        lp150.1.1
Summary:        Database management in a single PHP file
License:        GPL-2.0 OR Apache-2.0
Group:          Productivity/Networking/Web/Frontends

Url:            https://www.adminer.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-httpd.conf
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  php-tokenizer
BuildRequires:  xz
Requires:       adminer-database-support = %{version}
Requires:       mod_php_any
Requires:       php-iconv
Requires:       php-mbstring
Requires:       php-session
Requires:       php-zlib
Suggests:       adminer-mysql

%description
Adminer (formerly phpMinAdmin) is a full-featured database management tool
written in PHP. Conversely to phpMyAdmin, it consist of a single file ready to
deploy to the target server. Adminer is available for MySQL, PostgreSQL, SQLite,
MS SQL, Oracle, Firebird, SimpleDB, Elasticsearch and MongoDB.


%package editor
Summary:        Data manipulation for end-users
Group:          Productivity/Networking/Web/Frontends
Requires:       adminer = %{version}

%description editor
Adminer Editor is both easy-to-use and user-friendly database data editing tool
written in PHP. It is suitable for common users, as it provides high-level data
manipulation.


%package designs
Summary:        Alternative designs
Group:          Productivity/Networking/Web/Frontends
Requires:       adminer = %{version}

%description designs
Alternative designs for Adminer. Update the symbolic link at
%{apache_datadir}/%{name}/adminer.css to target the desired theme found in
%{apache_datadir}/%{name}/designs/*/adminer.css.

# Define adminer-database-support packages
%package elasticsearch
Summary:        Dependencies required for Adminer ElasticSearch support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pear-horde_elasticsearch

%description elasticsearch
Virtual package that requires dependencies needed for Adminer ElasticSearch support


%package firebird
Summary:        Dependencies required for Adminer Firebird SQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-firebird

%description firebird
Virtual package that requires dependencies needed for Adminer Firebird SQL support


%package mongodb
Summary:        Dependencies required for Adminer MongoDB support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pear-horde_mongo

%description mongodb
Virtual package that requires dependencies needed for Adminer MongoDB support


%package mssql
Summary:        Dependencies required for Adminer MS SQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-mssql

%description mssql
Virtual package that requires dependencies needed for Adminer MS SQL support


%package mysql
Summary:        Dependencies required for Adminer MySQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-mysql

%description mysql
Virtual package that requires dependencies needed for Adminer MySQL support


%package pgsql
Summary:        Dependencies required for Adminer PostgreSQL support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-pgsql

%description pgsql
Virtual package that requires dependencies needed for Adminer PostgreSQL support


%package sqlite
Summary:        Dependencies required for Adminer SQLite support
Group:          Productivity/Networking/Web/Frontends
Provides:       adminer-database-support = %{version}
Requires:       adminer = %{version}
Requires:       php-sqlite

%description sqlite
Virtual package that requires dependencies needed for Adminer SQLite support


%prep
%setup -q

%build
# Creates: ./adminer-{version}.php.
./compile.php

# Creates: ./editor-{version}.php.
./compile.php editor

%install
# Remove version from file names.
%{__mv} adminer-%{version}.php adminer.php
%{__mv} editor-%{version}.php editor.php

# Install files in datadir.
%{__install} -d -m 0755 %{buildroot}%{apache_datadir}/%{name}
%{__cp} -R adminer.php editor.php designs/ \
  %{buildroot}%{apache_datadir}/%{name}

# Default to hever theme.
ln -s %{apache_datadir}/%{name}/designs/hever/adminer.css \
  %{buildroot}%{apache_datadir}/%{name}

%{__install} -D -m 0644 %{SOURCE1} %{buildroot}%{apache_sysconfdir}/conf.d/%{name}.conf
# Fix paths in httpd config.
sed -i -e "s,@apache_datadir@,%{apache_datadir},g" -e "s,@name@,%{name},g" \
  %{buildroot}%{apache_sysconfdir}/conf.d/%{name}.conf

# README for adminer-database-support packages
echo "Virtual package for Adminer database support" > README

%post
# Enable required apache modules.
if [ -x /usr/sbin/a2enmod ] ; then
  # Get installed php_version (5 or 7).
  php_version=$(php -v | grep '(cli)' | awk '{print $2}' | awk -F'.' '{print $1}')
  if [[ -n ${php_version} ]]; then
    a2enmod -q php${php_version} || a2enmod php${php_version}
    a2enmod -q version || a2enmod version
  fi
fi

%if 0%{?suse_version} < 1310
%restart_on_update apache2
#%%else
#systemctl try-restart apache2 &>/dev/null
%endif

%postun
%if 0%{?suse_version} < 1310
%restart_on_update apache2
#%%else
#systemctl try-restart apache2 &>/dev/null
%endif

%files
%defattr(-,root,root)
%doc changes.txt
%dir %{apache_datadir}/%{name}
%{apache_datadir}/%{name}/adminer.php
%{apache_datadir}/%{name}/designs/hever/
%config(noreplace) %{apache_datadir}/%{name}/adminer.css
%config(noreplace) %{apache_sysconfdir}/conf.d/%{name}.conf

%files editor
%defattr(-,root,root)
%{apache_datadir}/%{name}/editor.php

%files designs
%defattr(-,root,root)
%{apache_datadir}/%{name}/designs/
%exclude %{apache_datadir}/%{name}/designs/hever/

# Define adminer-database-support packages
%if %{with elasticsearch}
%files elasticsearch
%defattr(-,root,root)
%doc README
%endif

%files firebird
%defattr(-,root,root)
%doc README

%if %{with mongodb}
%files mongodb
%defattr(-,root,root)
%doc README
%endif

%if %{with mssql}
%files mssql
%defattr(-,root,root)
%doc README
%endif

%files mysql
%defattr(-,root,root)
%doc README

%files pgsql
%defattr(-,root,root)
%doc README

%files sqlite
%defattr(-,root,root)
%doc README

%changelog
* Tue Feb 20 2018 jimmy@boombatower.com
- Update to version 4.6.2:
  * Release 4.6.2
  * Fix test
  * Fix typo
  * Comment
  * Use function after declaring it
  * Remove test server
  * Make test works with MariaDB
  * Make test work on wide screen
  * Editor: Fix displaying of true boolean values
  * Comment
  * Store current version before authentication and in Editor
  * Update design (thanks to Jan)
  * Add missing fullstop
  * Version 4.6.1.1 (#254)
  * Turkish language file updated.
  * Align Whole result
  * Always hide import
  * Print email only with rows or page
  * Move import out of footer
  * Move pagination to fieldset
  * Update readme
  * Make Login test work with jush-textarea
  * Add SQLite test
  * Test warnings
  * Convert tests to Katalon
  * Promote MongoDB, demote Oracle and MS SQL
  * Capitalize Whole result
  * Fill footer to the right
  * Make footer smaller
  * Move pagination outside footer
  * Wrap more into if (!is_ajax)
  * Move <p>
  * PostgreSQL: Add IF EXISTS to DROP SEQUENCE in export (bug #595)
  * Make footer border more obvious
  * Make footer margin not transparent
  * Centralize oninput
  * Speed up alter table
  * Use Unicode arrows in alt
  * Avoid hiding column only to show it later
  * Respect unchecked Default values
  * Update UI when coming from history
  * PostgreSQL: Fix exporting string default values (thanks to PotatoPangolin)
  * Semi-transparent border on table actions
  * Fix exporting sequences in PostgreSQL 10
  * Do not append empty values
  * Shorten JSON values in select (bug #594)
  * Fix id in databases list
  * Suggest updating Git submodules
  * Declare MariaDB support
* Fri Feb  9 2018 jimmy@boombatower.com
- Update to version 4.6.1:
  * Release 4.6.1
  * Round 9.2 to 9.2
  * MariaDB: Links to documentation in syntax highlighting
  * Display notification about performing action after relogin
  * Reorder changes
  * Allow specifying server name displayed in breadcrumbs
  * MariaDB: Links to documentation
  * Reorder changes
  * Remove .lcZ from timeFormat (bug #593)
  * Add todo
  * Add more system tables help links
  * Respect empty tableName in tablesPrint
  * Use tableName() in table.inc.php
  * Avoid qsl in a loop
  * Support Shift+click in server export
  * Avoid qsl in a loop
  * Sticky position of table actions
  * Document regression
  * Avoid qsl in check[]
  * Avoid qsl in a loop
  * Mark optional parameter
  * SQLite: Support ` in PRIMARY KEY
  * Avoid Invalid credentials with no credentials
  * SQLite: Allow deleting PRIMARY KEY from tables with auto increment
  * Do not wrap alter table thead
  * Add version() to use in plugins
  * Select original if nothing else is selected
  * Remove nested array
  * Support connecting to MySQL via SSL
  * Display Invalid credentials if connection error is empty
  * Delete unused functions
  * Ignore functions in Min_Driver
  * Remove unnecessary quotes
  * Add truncate_sql to PostgreSQL
  * PostgreSQL: Unescape bytea fields
  * Save bytes
  * Add missing function to compile.php
  * PostgreSQL: Upload binary files to bytea fields
  * Allow using number_type() as pattern
  * Translate thousands separator in JS
  * Editor: Use type=search for Search tables
  * Move tableCheck() below </form>
  * Pass operator from db.inc.php
  * PostgreSQL: Cast to string when searching using LIKE (bug #325)
  * MySQL: Support non-utf8 charset in search in column
  * Use ST_GeomFromText in MySQL 8 (bug #574)
  * Do not modify $_GET["where"]
  * Display empty operator as LIKE %%%%
  * Fix whitespace
  * Avoid deprecated each()
  * PostgreSQL: Fix condition for selecting no rows
  * Fix error display in Search tables
  * PostgreSQL: Don't treat interval type as number (bug #474)
  * Pass required parameter
  * Use existing variable
  * Add class to use in designs
  * Use primary key instead of LIMIT 1 if available
* Mon Feb  5 2018 jimmy@boombatower.com
- Update to version 4.6.0:
  * Release 4.6.0
  * Fix affected rows after getting warnings
  * Fix number of affected rows after getting warnings
  * Fix test
  * Fix 5.1 being displayed as 5.09999...
  * PRIMARY KEY in SQLite
  * Add design Esterka
  * Disable autocompleting password on create user page
  * Use primary key to edit rows even if not selected
  * Space between DB and Use
  * Translate DB
  * Select converted fields only once
  * Don't count rows if we reached the end
  * Fix count_rows with more than one group by column
  * Use separator in limit1
  * SQLite: Limit rows in data manipulation without unique key
  * Document that tests don't work with oninput
  * PostgreSQL: Limit rows in data manipulation without unique key
  * Don't use ctid as it's not stable
  * Move variables close to their usage
  * Limit non-unique where updates
  * Use Oid as the name of the column
  * Save bytes
  * Update rmsoft design
  * MySQL: Add FIND_IN_SET search operator
  * Add rmsoft design
  * MySQL: Add floor and ceil functions
  * Fix links to PostgreSQL 10 documentation
  * Delete unused variable
  * Display options for timestamp columns when creating a new table (thanks to Robert Vlach)
  * Don't display warnings for failed queries
  * Fix variable name
  * Reorder variables
  * Use pg_last_notice only with pgsql
  * Print warnings in call
  * Pass start time to selectQuery
  * PostgreSQL: Display warnings
  * Return string from warnings()
  * Display warnings in messages
  * Show select warnings
  * Support X-Forwarded-Prefix (e.g. Traefik PathPrefixStrip feature)
  * Lowercase EXPLAIN but don't translate it
  * Move explain below warnings
  * Fix return type
  * MySQL: Display warnings in SQL command
  * Quote default values not starting with a letter
  * Stop redirecting links via adminer.org
  * Fix min_version use
  * Quote dates in default value
  * Fully support functions in default values
  * Fix min_version use
  * PostgreSQL: Allow now() as default value (bug #525)
  * Fix edit_type after 1f21cd43
  * PostgreSQL: Allow editing views with uppercase letters (bug #467)
  * PostgreSQL: Allow creating trigger functions
  * Add placeholders
  * PostgreSQL: Support functions
  * Add min_version to compile.php
  * SimpleDB: Document that allow_url_fopen is required (bug #340)
  * Focus correct field in selectSearch
  * Support JSON since MariaDB 10.2 (bug #590)
  * Use min_version
  * Add min_version
  * Save bytes
  * add malay translation
  * Added and translated missing keys in polish translation
  * Update compatibility with TinyMCE v4 (#247)
  * Fix elastic after ef5a7639
  * fix elastic.inc.php to work on PHP 5.2
  * Fix counting selected rows after going back to select page
* Thu Jan 25 2018 jimmy@boombatower.com
- Update to version 4.5.0:
  * Release 4.5.0
  * Fix tests after 95d02bb9
  * Simplify drop object confirmation questions
  * Translate message added in 4.4.0
  * Display name of the object in confirmation when dropping it
  * Display error when getting row to edit
  * Avoid CONVERT() except in MySQL (bug #509)
  * Bump version
  * MySQL: Support routines with comments in parameters (bug #460)
  * Verify if adminer.version was created on www.adminer.org
  * Store current Adminer version server-side to avoid excessive requests
  * Send token as last param
  * Allow using adminer.invalid by other users in a group
  * Extract file_open_lock and file_write_unlock
  * Display boolean values as code (bug #562)
  * MariaDB: Support fulltext and spatial indexes in InnoDB (bug #583)
  * PostgreSQL: Display foreign tables (bug #576)
  * Add designs.php
  * Fix compiled version after 5cc831c1
  * Hide window.opener from pages opened in a new window (bug #561)
  * Fix GPL version
  * Add plugin for switching designs
  * Display bold parts of error (bug #565)
  * Add bottom border to last cells
  * Editor: Fix displaying of false values in PostgreSQL (bug #568)
  * Decrease float precision (bug #578)
  * Add ability to override file name (path) when loading dump from webserver
  * Support current_timestamp() as default of time fields (bug #572)
  * Display newlines in column comments (bug #573)
  * MySQL: Support geometry in MySQL 8 (bug #574)
  * MSSQL driver fixed for freetds drivers. See bug #167, #291
  * Fix search focus (regression from 4.4.0)
  * Compatibility with PHP < 5.3
  * Add mongodb as a possible driver
  * Save bytes
  * php7 support with minimal changes of original code
  * PostgreSQL: Export DROP SEQUENCE if dropping table
  * PostgreSQL: Do not export triggers if not requested
  * Ignore removed CREATE+ALTER mode in trigger_sql()
  * Fix whitespace
  * CSP: Allow any CSS
  * adminer-theme-mancave2-2.0.alpha
  * Fix NULL value in edit form with Postgres
  * Do not warn about MySQL specific functions
  * Fix single driver non-MySQL compiled versions (regression from 150301ed)
  * Hide driver selection in single-driver version (regression from e762a6aa)
  * Unify HTML for list of tables in Editor according to Adminer
  * Encapsulate fulltext part in search box into <div>
  * Enhance ElasticSearch integration
  * Allow PHP 5.6 in Travis
  * Select numeric database name in DB list (bug #580)
  * SQLite: Enable foreign key checks
  * CSP: Allow any images, media and fonts, disallow base-uri
  * Define JS functions in AdminerTablesFilter sooner
  * Adminer: Fix Search data in tables
* Wed Jan 17 2018 jimmy@boombatower.com
- s/or/OR/ in License.
- Update to version 4.4.0:
  * Release 4.4.0
  * Allow sending multiple CSP headers
  * Use __construct for constructor
  * Set session cache limiter only without session.auto_start (bug #586)
  * Add missing newline
  * Require specifying credentials in login-sqlite plugin
  * Avoid count(null)
  * Disallow PHP 5.3 in Travis
  * Disallow connecting to privileged ports (thanks to hyp3rlinx)
  * Rate limit password-less login attempts from the same IP address (thanks to hyp3rlinx)
  * Use HTTPS
  * Use HTTPS in doc_link()
  * Do not set '' for empty enum
  * Fix select function onchange
  * Clone all event handlers in cloneNode()
  * Use border-collapse to prevent unnecessary wrapping in Chrome
  * Fix whitespace
  * Fix selectCount() in information_schema
  * Fix SQL command toggle
  * Disallow scripts without nonce
  * Fix wrapping in Create table
  * Use script_src for <script src>
  * Fix typo in script()
  * Do not send empty CSP
  * Move inline event handlers to <script>
  * Move inline event handlers to <script>
  * Use the fact that we handle oninput in whisper()
  * Move inline event handlers to <script>
  * Editor: Fix Search data in tables
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler for skipping original
  * Move inline event handlers to <script>
  * Return false from editingMoveRow()
  * Move inline event handlers to <script>
  * Use oninput instead of onchange
  * Move inline event handlers to <script>
  * Fix fieldChange() after 6353a898
  * Use oninput instead of onkeyup
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler in on_help()
  * Move inline event handlers to <script>
  * Clone onchange in cloneNode()
  * Move inline event handlers to <script>
  * Allow searching data in tables by Ctrl+Enter
  * Move inline event handlers to <script>
  * Fix selectors in schema after 58b2904d
  * Rely on event always passed to handlers
  * Move inline event handlers to <script>
  * Return false from editingRemoveRow
  * Move inline event handlers to <script>
  * Use script() for <script>
  * Move inline event handlers to <script>
  * Use <script> instead of inline event handler in print_fieldset()
  * Use <script> instead of inline event handler in confirm()
  * Move inline event handlers to <script>
  * Return false from ajaxSetHtml()
  * Move inline event handlers to <script>
  * Revert using @this in formChecked
  * Move inline event handlers to <script>
  * Return false from toggle()
  * onchange='selectFieldChange
  * Use @this in selectFieldChange
  * Move inline event handlers to <script>
  * Fix indexesAddColumn after 14778165
  * Move inline event handlers to <script>
  * Revert using @this in formChecked
  * Allow customizing CSP
  * Allow img-src data: common in skins
  * Use JSON.parse if available
  * Add Content Security Policy
  * Always send security headers in customization
  * Add nosniff header
  * Use Referrer-Policy instead of <meta name="referrer">
  * Editor: Fix doubleclick on database page
  * Fix a typo from 9cb28186
  * Use @this in JavaScript (prepares for removing inline event handlers)
  * Prevent PHP 7.1 warning about non-numeric values
  * Unindent doc-comments
  * Delete type="text/css" from <style> as it is the default in HTML5
  * Delete type="text/javascript" from <script> as it is the default in HTML5
  * Replace getElementsByTagName by shortcut for querySelectorAll
  * Use querySelector
  * Replace getElementById by shortcut for querySelector (requires IE8)
  * Fix skin for Chrome 61 (thanks to Dominik Ulrich)
  * Editor: Display field comment's text inside [] only in edit form
  * Fix hebrew typos (#228)
  * Add new Hebrew translations
  * Add Hebrew translation
  * Editor: Don't set time zone from PHP
  * Make sure all sidebar elements are pushed down, not just the form.
  * Update AdminerTablesFilter to produce li as per c9801e2e2418
  * MySQL: Remove dedicated view for replication status
  * Sort table names (bug #552)
  * Update es.inc.php
  * Add a donate link
* Sat Oct 28 2017 jimmy@boombatower.com
- Disable elasticsearch and mssql since the dependencies are no
  longer present in Factory.
* Mon Sep 11 2017 jimmy@boombatower.com
- Update a2enmod php5 to check for php version (boo#1058106).
* Fri Apr 14 2017 jimmy@boombatower.com
- Update to version 4.3.1:
  * PostgreSQL: Fix index size computation in PostgreSQL < 9.0 (reverts 4c78976c)
  * Fix PostgreSQL nullable fields in export
  * Fix table dependency on export
  * Updating Russian translation
  * Update haeckel design (thanks to Klemens Haeckel)
  * PostgreSQL: Support JSON and JSONB data types (bug #542)
  * PostgreSQL: Fix JSONB version support
  * Don't overwrite previous cookies (bug #539)
  * Add a todo
  * Fix SQL command autofocus
  * Release 4.3.1
* Wed Mar 15 2017 jimmy@boombatower.com
- Update to version 4.3.0:
  * Update Indonesian translation (thanks to Benny)
  * Add accessibility labels to Create Table fields
  * Make maxlength in edit fields a soft limit
  * Add Cache-Control: immutable to static files
  * Change comment not supported by compile.php
  * Changed 'geraakt' to 'beinvloed' in Dutch translation
  * Disallow selecting driver if there's only one
  * Add SQLite auto-login plugin
  * RTL layout fixes
  * Additional theme with responsive and RTL support
  * Escape quote in field name to make it work in Chrome (thanks to zcepenela pani)
  * Add accessibility labels to databases and tables checkboxes
  * Use class instead inline style
  * Add accessibility labels to Indexes
  * Add accessibility labels to Foreign keys
  * mistype correction
  * Fix error found by PHPStan
  * postgresql : unique partial index musn't be considered as unique. can cause problems on row edition
  * postgresql : ERROR: function connection_id() does not exist
  * PHP Warning hidden and better parsing times (at least for postgresql)
  * Plugin which shows sql structure comments in field names title
  * Fixed mssql driver for usage with microsoft's php7 sqlsrv extension
  * Changed 'undefined' to 'null'
  * Use null instead of undefined on after parsing JSON
  * Added pdo_dblib as a driver for MSSQL (as native MSSQL driver does not exist for PHP7)
  * Document changes
  * Fixed background of the list of the tables.
  * postgresql error with index on hidden columns (ctid)
  * Fix index length with Postgresql
  * Tabs must also be escaped in JSON strings
  * Plugin: Use <select> on custom user types in psql
  * Added support for binary foreign keys selection on edit
  * Update AdminerTablesFilter
  * AdminerTablesFilter: Persist filter value in a tab
  * Improve limit check in edit-foreign plugin
  * fixed Elastic table_status()
  * Handle checkboxes properly in selectAddRow()
  * Move rendering of table structure and indexes list into plugin system
  * Add plugin for printing table structure in expanded format
  * Add plugin for printing table indexes structure in expanded format
  * PostgreSQL export: table structure, columns, sequences, indexes, foreign keys, comments, trigger definition
  * make bytea fields shortable
  * New skin 'flat'
  * Do not set input type as numeric if field is an array
  * Add namespace to routine call
  * Edit json and jsonb types in textarea
  * Breadcumb no longer blocks the logout button.
  * Hide databases the user can't connect to
  * fix logger for SQL commands
  * Fix MS SQL Driver to not show warnings for version fetching on connection and to retrieve the next set of results properly
  * Changed NULL format
  * Tables list implemented as <ul>
  * foreign key link fix - added missing ns
  * Add javascript move for editing
  * Verify commit success after import.
  * PostgreSQL: Fix index size computation
  * PostgreSQL: Allow changing materialized views
  * Fixed all alternative designs after changes in a list of tables made here: https://github.com/vrana/adminer/pull/116
  * Checkbox for bool in psql
  * Add basic support for MySQL replication
  * Add Czech translation
  * Display message about missing master status
  * Add jsonly class to JS checkboxes
  * Fix where() escaping in MS SQL (bug #496)
  * Support high Unicode characters in shorten_utf8 (bug #481)
  * Use 'Create database' instead of 'Create new database'
  * Move 'Create user' above the list of users
  * Fix dropping foreign keys linking to other database
  * MySQL: Support spatial indexes (bug #455)
  * Save bytes
  * Elasticsearch: Support HTTPS by inputting https://server (bug #446)
  * Unindent
  * Hide materialized views in MySQL
  * Elasticsearch: allow empty server name
  * Bump version
  * Avoid referencing global variable (doesn't work in PHP 7.1 if Adminer is included inside a function)
  * Document new engines
  * Simplify SQLite development
  * Lint PHP files
  * Save bytes
  * Update URL
  * Improve SQLite login error message
  * Rely on noreferrer in Firefox too
  * Use SameSite cookies (except session cookie)
  * Support MySQL 8
  * MySQL: Support JSON data type
  * Print number of bytes in blob in italics
  * Highlight JSON
  * Update JUSH
  * Reorder changelog
  * Release 4.3.0
- Utilize version rewrite to drop v from tag.
* Sun Jan 22 2017 chris@computersalat.de
- fix adminer-http.conf file
  * absence of 'mod_version' is no guarantee to be on apache < 2.4
* Wed Jun  1 2016 jimmy@boombatower.com
- Update to version v4.2.5:
  + Fix http:// links in stylesheets to protocol-independent ones (//)
  + improved kill command support for MySQL and initial support for PgSQL
  + Remove global variable
  + Fix remote execution in SQLite query (thanks to Vincent Waart)
  + SQLite: Require credentials to use (thanks to Vincent Waart)
  + Release 4.2.5
* Tue Feb  9 2016 jimmy@boombatower.com
- Update to 4.2.4.
  + Add escaping (not fixing any XSS)
  + Release 4.2.3
  + Use HTTPS Google Font URL
  + Support PHP 7
  + Delete unused variable and method
  + Bosnian language
  + Add Bosnian translation
  + Add Finnish translation
  + Fix remote execution in SQLite query (discovered by 庞申杰(千霄))
  + Release 4.2.4
* Wed Dec  9 2015 jimmy@boombatower.com
- Correct elasticsearch and mongodb virtual package requires.
- Add %%bcond_with mongodb until submitted to Factory.
* Tue Nov 24 2015 jimmy@boombatower.com
- Correct license to 'GPL-2.0 or Apache-2.0'.
* Mon Nov 16 2015 jimmy@boombatower.com
- Update to 4.2.3.
* Fri Nov 13 2015 aj@ajaissle.de
- Spec file reworked, adjusted apache2 conf.
* Sat Aug  8 2015 jimmy@boombatower.com
- Update to 4.2.2.
* Wed Jul  1 2015 jimmy@boombatower.com
- Initial import of 4.2.1.
